from fastapi import APIRouter
from sqlmodel import select

from xmpp_api.db import UserDep, SessionDep
from xmpp_api.db.bot import Bot
from xmpp_api.api.types.bot import BotInformation
from xmpp_api.util.constraints import bot_constraint_from_db


router = APIRouter(prefix="/user")


@router.get("/bots")
def get_bots(user: UserDep, session: SessionDep) -> list[BotInformation]:
    bots = session.exec(select(Bot).where(Bot.owner_id == user.id)).all()
    return [
        BotInformation(
            id=bot.id,
            name=bot.name,
            description=bot.description,
            localpart=bot.localpart,
            constraints=[bot_constraint_from_db(c) for c in bot.constraints],
        )
        for bot in bots
    ]
