from typing import Annotated

from pydantic import BaseModel
from fastapi import Depends


class _ComponentConfig(BaseModel):
    # The JID of the component
    jid: str

    # Address of server's component port
    server: str

    # The component's secret.
    secret: str


class _Config(BaseModel):
    # DB URI for sqlmodel
    database: str

    # Component configuration
    component: _ComponentConfig


def load_config() -> _Config:
    """
    Load the application config
    """
    # TODO: Actually load it
    return _Config(
        database="sqlite:///db.sqlite3",
        component=_ComponentConfig(
            jid="test.localhost",
            server="localhost:5869",
            secret="abc123",
        ),
    )


ConfigDep = Annotated[_Config, Depends(load_config)]
